@@ -1,23 +1,33 @@
 import argparse
-import os
 import pathlib
 import shutil
 import stat
-import sys
 
 import git
 
 
-def install(*args, **kwargs):
-    """Install git post-checkout hook."""
+def install(force: bool) -> None:
+    """
+    Install git post-checkout hook.
+
+    :param force: overwrite hook if it exists.
+    """
     repo = git.Repo()
-    src = pathlib.Path(os.path.dirname(__file__)).joinpath("post_checkout.py")
-    dst = pathlib.Path(repo.git_dir).joinpath("hooks").joinpath("post-checkout")
+    src = pathlib.Path(__file__).parent / "post_checkout.py"
+    dst = pathlib.Path(repo.git_dir) / "hooks" / "post-checkout"
+
+    if dst.exists() and not force:
+        print(
+            "Error: another post-checkout hook has already been installed. "
+            "To overwrite it, use the --force option.",
+        )
+        exit(-1)
+
     shutil.copyfile(src, dst)
     dst.chmod(dst.stat().st_mode | stat.S_IEXEC)
 
 
-def main():
+def main() -> None:
     """
     Main entrypoint.
 
@@ -33,23 +43,26 @@ def main():
         metavar="",
         dest="subcommand",
     )
-    subparsers.add_parser(
+
+    install_cmd_parser = subparsers.add_parser(
         "install",
         help="install git hook",
-        add_help=False,
     )
-    subcommands = {
-        "install": install,
-    }
+    install_cmd_parser.add_argument(
+        "--force",
+        dest="force_install",
+        action="store_true",
+        default=False,
+        help="overwrite hook if it exists",
+    )
     args, _ = parser.parse_known_args()
 
     if args.subcommand is None:
         parser.print_help()
         return
 
-    command = subcommands[args.subcommand]
-    sys.argv.pop(0)
-    command(sys.argv[1:])
+    if args.subcommand == "install":
+        install(args.force_install)
 
 
 if __name__ == "__main__":
